==> apache-beam-2.5.0-source-release.zip: beam-release-2.5.0/sdks/java/extensions/sql/src/test/java/org/apache/beam/sdk/extensions/sql/impl/interpreter/operator/BeamSqlUdfExpressionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.sdk.extensions.sql.impl.interpreter.operator;

import com.google.common.collect.ImmutableMap;
import java.util.ArrayList;
import java.util.List;
import org.apache.beam.sdk.extensions.sql.impl.interpreter.BeamSqlFnExecutorTestBase;
import org.apache.calcite.sql.type.SqlTypeName;
import org.junit.Assert;
import org.junit.Test;

/** Test for BeamSqlUdfExpression. */
public class BeamSqlUdfExpressionTest extends BeamSqlFnExecutorTestBase {

  @Test
  public void testUdf() throws NoSuchMethodException, SecurityException {
    List<BeamSqlExpression> operands = new ArrayList<>();
    operands.add(BeamSqlPrimitive.of(SqlTypeName.INTEGER, 10));

    BeamSqlUdfExpression exp =
        new BeamSqlUdfExpression(
            UdfFn.class.getMethod("negative", Integer.class), operands, SqlTypeName.INTEGER);

    Assert.assertEquals(-10, exp.evaluate(row, null, ImmutableMap.of()).getValue());
  }

  /** UDF example. */
  public static final class UdfFn {
    public static int negative(Integer number) {
      return number == null ? 0 : 0 - number;
    }
  }
}

==> apache-beam-2.9.0-source-release.zip: beam-release-2.9.0/sdks/java/extensions/sql/src/test/java/org/apache/beam/sdk/extensions/sql/impl/interpreter/operator/BeamSqlUdfExpressionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.sdk.extensions.sql.impl.interpreter.operator;

import java.util.ArrayList;
import java.util.List;
import org.apache.beam.sdk.extensions.sql.impl.interpreter.BeamSqlExpressionEnvironments;
import org.apache.beam.sdk.extensions.sql.impl.interpreter.BeamSqlFnExecutorTestBase;
import org.apache.calcite.sql.type.SqlTypeName;
import org.junit.Assert;
import org.junit.Test;

/** Test for BeamSqlUdfExpression. */
public class BeamSqlUdfExpressionTest extends BeamSqlFnExecutorTestBase {

  @Test
  public void testUdf() throws NoSuchMethodException, SecurityException {
    List<BeamSqlExpression> operands = new ArrayList<>();
    operands.add(BeamSqlPrimitive.of(SqlTypeName.INTEGER, 10));

    BeamSqlUdfExpression exp =
        new BeamSqlUdfExpression(
            UdfFn.class.getMethod("negative", Integer.class), operands, SqlTypeName.INTEGER);

    Assert.assertEquals(
        -10, exp.evaluate(row, null, BeamSqlExpressionEnvironments.empty()).getValue());
  }

  /** UDF example. */
  public static final class UdfFn {
    public static int negative(Integer number) {
      return number == null ? 0 : 0 - number;
    }
  }
}
